@rem = '--*-Perl-*--
@echo off
if "%OS%" == "Windows_NT" goto WinNT
perl -x -S "%0" %1 %2 %3 %4 %5 %6 %7 %8 %9
goto endofperl
:WinNT
perl -x -S %0 %*
if NOT "%COMSPEC%" == "%SystemRoot%\system32\cmd.exe" goto endofperl
if %errorlevel% == 9009 echo You do not have Perl in your PATH.
if errorlevel 1 goto script_failed_so_exit_with_non_zero_val 2>nul
goto endofperl
@rem ';
#!perl
#line 15

our $DATE = '2015-03-21'; # DATE
our $VERSION = '0.15'; # VERSION

use 5.010;
use strict;
use warnings;

use App::ProgUtils;
use Perinci::CmdLine::Any;

our %SPEC;
$SPEC{progless} = {
    v => 1.1,
    summary => 'Show program file with `less`',
    description => <<'_',

Basically

    % progless PROG

is roughly the same as:

    % less `which PROG`

except that it offers tab completion and can also search PROG in the current
directory or normal path (e.g. `progless ../bin/foo`).

_
    args => {
        program => {
            schema => 'str*',
            req => 1,
            pos => 0,
            completion => $App::ProgUtils::_complete_program,
        },
    },
    deps => {
        prog => 'less',
    },
};
sub progless {
    my %args = @_;
    exec "less", App::ProgUtils::_search_program($args{program});
    # [200]; # unreached
}

Perinci::CmdLine::Any->new(
    url => '/main/progless',
)->run;

# ABSTRACT: Show program file with `less`
# PODNAME: progless

__END__

=pod

=encoding UTF-8

=head1 NAME

progless - Show program file with `less`

=head1 VERSION

This document describes version 0.15 of progless (from Perl distribution App-ProgUtils), released on 2015-03-21.

=head1 SYNOPSIS

Basic usage:

 % progless mpath

=head1 DESCRIPTION

Basically

 % progless PROG

is roughly the same as:

 % less C<which PROG>

except that it offers tab completion and can also search PROG in the current
directory or normal path (e.g. C<progless ../bin/foo>).

=head1 OPTIONS

C<*> marks required options.

=over

=item B<--config-path>=I<s>

Set path to configuration file.

Can be specified multiple times.

=item B<--config-profile>=I<s>

Set configuration profile to use.

=item B<--format>=I<s>

Choose output format, e.g. json, text.

Default value:

 undef

=item B<--help>, B<-h>, B<-?>

Display this help message.

=item B<--json>

Set output format to json.

=item B<--naked-res>

When outputing as JSON, strip result envelope.

Default value:

 0

By default, when outputing as JSON, the full enveloped result is returned, e.g.:

    [200,"OK",[1,2,3],{"func.extra"=>4}]

The reason is so you can get the status (1st element), status message (2nd
element) as well as result metadata/extra result (4th element) instead of just
the result (3rd element). However, sometimes you want just the result, e.g. when
you want to pipe the result for more post-processing. In this case you can use
`--naked-res` so you just get:

    [1,2,3]


=item B<--no-config>

Do not use any configuration file.

=item B<--program>=I<s>*

=item B<--version>, B<-v>

=back

=head1 ENVIRONMENT

PROGLESS_OPT

=head1 FILES

~/progless.conf

/etc/progless.conf

=head1 COMPLETION

This script has shell tab completion capability with support for several shells.

=head2 bash

To activate bash completion for this script, put:

 complete -C progless progless

in your bash startup (e.g. C<~/.bashrc>). Your next shell session will then recognize tab completion for the command. Or, you can also directly execute the line above in your shell to activate immediately.

It is recommended, however, that you install L<shcompgen> which allows you to activate completion scripts for several kinds of scripts on multiple shells. Some CPAN distributions (those that are built with L<Dist::Zilla::Plugin::GenShellCompletion>) will even automatically enable shell completion for their included scripts (using C<shcompgen>) at installation time, so you can immadiately have tab completion.

=head2 tcsh

To activate tcsh completion for this script, put:

 complete progless 'p/*/`progless`/'

in your tcsh startup (e.g. C<~/.tcshrc>). Your next shell session will then recognize tab completion for the command. Or, you can also directly execute the line above in your shell to activate immediately.

It is also recommended to install C<shcompgen> (see above).

=head2 other shells

For fish and zsh, install C<shcompgen> as described above.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-ProgUtils>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-ProgUtils>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-ProgUtils>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

__END__
:endofperl
